#!/usr/bin/python3
from datetime import datetime, timedelta
import getopt
import os
import sys
import time

def main(argv):

    folder = False
    numberOfBackups = False

    # Checks if the correct parameters were given when launched via command line 
    try:
        opts, args = getopt.getopt(argv, "f:n:")
    except getopt.GetoptError:
        print('usage: fake_backups.py -f <folder> -n <number of backups>')
        sys.exit(2)
    for opt, arg in opts:
        if opt in ('-f'):
            # -f must be a folder
            if os.path.isdir(arg):
                folder = arg
            else:
                print('Please specify a valid path for argument -f <folder>.')
                sys.exit(2)
        elif opt in ('-n'):
            # -n must be an integer
            try:
                numberOfBackups = int(arg)
            except ValueError:
                print('Please specify a valid number for argument -n <number of backups>.')
    if folder and numberOfBackups:
        i = 0
        # Creates numberOfBackups empty files named with the name of the service + the current date minus number of iterations
        start = time.time()
        while(i < numberOfBackups):
            d = datetime.today() - timedelta(hours=i)
            filename = d.strftime('%Y.%m.%d.%H%M%S')
            file = open(folder + '/' + filename + '.tar.gz', 'w')
            file.close()
            i += 1
        end = time.time()
        time_elapsed = end - start

    print('[' + folder + '/' + ']')
    # Displays the time needed to generate all files
    print(str(i) + ' files generated in ' + str(time_elapsed) + ' seconds.')

if __name__ == "__main__":
    main(sys.argv[1:])
